summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStefano Lattarini <stefano.lattarini@gmail.com>2012-10-26 12:52:35 +0200
committerStefano Lattarini <stefano.lattarini@gmail.com>2012-10-26 14:22:27 +0200
commit926ab5b475fe77960a81ea608ea1948dc7d3b4b6 (patch)
treef964a7290e3b1e4d3071aa01e3a07ecc8051842c
parent83caec4ed340657634fff930f45d2c9e4d60007c (diff)
downloadautomake-926ab5b475fe77960a81ea608ea1948dc7d3b4b6.tar.gz
tests: rename some test to more expressive names
* t/remake.sh: Rename ... * t/remake-subdir-grepping.sh: ... like this. * t/remake8a.sh: Rename ... * t/remake-makefile-intree.sh: ... like this, and adjust comments. * t/remake8b.sh: Rename ... * t/remake-makefile-vpath.sh: ... like this, and adjust comments. * t/remake9a.sh: Rename ... * t/remake-after-configure-ac.sh: ... like this, and adjust comments. * t/remake9b.sh: Rename ... * t/remake-after-makefile-am.sh: ... like this, and adjust comments. * t/remake9c.sh: Rename ... * t/remake-after-acinclude-m4.sh: ... like this, and adjust comments. * t/remake9d.sh: Rename ... * t/remake-after-aclocal-m4.sh: ... like this, and adjust comments. * t/remake10a.sh: Rename ... * t/remake-include-configure.sh: ... like this, and adjust comments. * t/remake10b.sh: Rename ... * t/remake-include-makefile.sh: ... like this, and adjust comments. * t/remake10c.sh: Rename ... * t/remake-include-aclocal.sh: ... like this, and adjust comments. * t/list-of-tests.mk: Adjust. Signed-off-by: Stefano Lattarini <stefano.lattarini@gmail.com>
-rw-r--r--t/list-of-tests.mk26
-rwxr-xr-xt/remake-after-acinclude-m4.sh (renamed from t/remake9c.sh)2
-rwxr-xr-xt/remake-after-aclocal-m4.sh (renamed from t/remake9d.sh)2
-rwxr-xr-xt/remake-after-configure-ac.sh (renamed from t/remake9a.sh)2
-rwxr-xr-xt/remake-after-makefile-am.sh (renamed from t/remake9b.sh)2
-rwxr-xr-xt/remake-include-aclocal.sh (renamed from t/remake10c.sh)5
-rwxr-xr-xt/remake-include-configure.sh (renamed from t/remake10a.sh)5
-rwxr-xr-xt/remake-include-makefile.sh (renamed from t/remake10b.sh)6
-rwxr-xr-xt/remake-makefile-intree.sh (renamed from t/remake8a.sh)6
-rwxr-xr-xt/remake-makefile-vpath.sh (renamed from t/remake8b.sh)6
-rwxr-xr-xt/remake-subdir-grepping.sh (renamed from t/remake.sh)2
-rwxr-xr-xt/remake-subdir-only.sh (renamed from t/remake1a.sh)2
12 files changed, 35 insertions, 31 deletions
diff --git a/t/list-of-tests.mk b/t/list-of-tests.mk
index b3ff6b2ba..cbe7dc152 100644
--- a/t/list-of-tests.mk
+++ b/t/list-of-tests.mk
@@ -903,8 +903,6 @@ t/python-pr10995.sh \
t/recurs.sh \
t/recurs2.sh \
t/relativize.tap \
-t/remake.sh \
-t/remake1a.sh \
t/remake2.sh \
t/remake3.sh \
t/remake3a.sh \
@@ -912,23 +910,25 @@ t/remake4.sh \
t/remake5.sh \
t/remake6.sh \
t/remake7.sh \
-t/remake8a.sh \
-t/remake8b.sh \
-t/remake9a.sh \
-t/remake9b.sh \
-t/remake9c.sh \
-t/remake9d.sh \
-t/remake10a.sh \
-t/remake10b.sh \
-t/remake10c.sh \
+t/remake-makefile-intree.sh \
+t/remake-makefile-vpath.sh \
+t/remake-after-configure-ac.sh \
+t/remake-after-makefile-am.sh \
+t/remake-after-acinclude-m4.sh \
+t/remake-after-aclocal-m4.sh \
+t/remake-include-configure.sh \
+t/remake-include-makefile.sh \
+t/remake-include-aclocal.sh \
t/remake11.sh \
t/remake12.sh \
t/remake-all-1.sh \
t/remake-all-2.sh \
-t/remake-subdir-from-subdir.sh \
-t/remake-subdir-gnu.sh \
t/remake-subdir.sh \
t/remake-subdir2.sh \
+t/remake-subdir-only.sh \
+t/remake-subdir-grepping.sh \
+t/remake-subdir-from-subdir.sh \
+t/remake-subdir-gnu.sh \
t/remake-subdir-long-time.sh \
t/remake-gnulib-add-acsubst.sh \
t/remake-gnulib-add-header.sh \
diff --git a/t/remake9c.sh b/t/remake-after-acinclude-m4.sh
index 402bef9c9..7c899dc2a 100755
--- a/t/remake9c.sh
+++ b/t/remake-after-acinclude-m4.sh
@@ -15,7 +15,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules when acinclude.m4 or its prerequisites change.
-# Keep in sync with the other sister tests 'remake9*.sh'.
+# Keep in sync with the other sister tests 'remake-after-*.sh'.
. ./defs || exit 1
diff --git a/t/remake9d.sh b/t/remake-after-aclocal-m4.sh
index 1cf3fdf36..45d7a6a94 100755
--- a/t/remake9d.sh
+++ b/t/remake-after-aclocal-m4.sh
@@ -15,7 +15,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules when aclocal.m4 or its prerequisites change.
-# Keep in sync with the other sister tests 'remake9*.sh'.
+# Keep in sync with the other sister tests 'remake-after-*.sh'.
. ./defs || exit 1
diff --git a/t/remake9a.sh b/t/remake-after-configure-ac.sh
index 3e239c9c3..ee178b1c7 100755
--- a/t/remake9a.sh
+++ b/t/remake-after-configure-ac.sh
@@ -15,7 +15,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules when configure.ac or its prerequisites change.
-# Keep in sync with the other sister tests 'remake9*.sh'.
+# Keep in sync with the other sister tests 'remake-after-*.sh'.
. ./defs || exit 1
diff --git a/t/remake9b.sh b/t/remake-after-makefile-am.sh
index aee41c4c4..fca90b637 100755
--- a/t/remake9b.sh
+++ b/t/remake-after-makefile-am.sh
@@ -15,7 +15,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules when Makefile.am or its prerequisites change.
-# Keep in sync with the other sister tests 'remake9*.sh'.
+# Keep in sync with the other sister tests 'remake-after-*.sh'.
. ./defs || exit 1
diff --git a/t/remake10c.sh b/t/remake-include-aclocal.sh
index 62fe29a87..df1870e19 100755
--- a/t/remake10c.sh
+++ b/t/remake-include-aclocal.sh
@@ -15,8 +15,9 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules for m4 files included (also recursively) by
-# aclocal.m4.
-# Keep in sync with sister tests 'remake10a.sh' and 'remake10b.sh'.
+# aclocal.m4. Keep in sync with sister tests:
+# - remake-include-configure.sh
+# - remake-include-makefile.sh
. ./defs || exit 1
diff --git a/t/remake10a.sh b/t/remake-include-configure.sh
index e91503bbd..f7f8c0450 100755
--- a/t/remake10a.sh
+++ b/t/remake-include-configure.sh
@@ -15,8 +15,9 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules for m4 files included (also recursively) by
-# configure.ac.
-# Keep in sync with sister tests 'remake10b.sh' and 'remake10c.sh'.
+# configure.ac. Keep in sync with sister tests:
+# - remake-include-aclocal.sh
+# - remake-include-makefile.sh
. ./defs || exit 1
diff --git a/t/remake10b.sh b/t/remake-include-makefile.sh
index 2c6e22a5d..ed749ccee 100755
--- a/t/remake10b.sh
+++ b/t/remake-include-makefile.sh
@@ -15,8 +15,10 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test remake rules for am files included (also recursively) by
-# Makefile.am.
-# Keep in sync with sister tests 'remake10a.sh' and 'remake10c.sh'.
+# Makefile.am. Keep in sync with sister tests:
+# - remake-include-aclocal.sh
+# - remake-include-configure.sh
+
. ./defs || exit 1
diff --git a/t/remake.sh b/t/remake-subdir-grepping.sh
index bd39792a2..a8afc402e 100755
--- a/t/remake.sh
+++ b/t/remake-subdir-grepping.sh
@@ -16,7 +16,7 @@
# Weak "grepping" test trying to ensure that remaking rules in a subdir
# are correctly generated.
-# See also sister functional test 'remake1a.sh'.
+# See also sister functional test 'remake-subdir-only.sh'.
. ./defs || exit 1
diff --git a/t/remake1a.sh b/t/remake-subdir-only.sh
index cdf494aad..12d1ca544 100755
--- a/t/remake1a.sh
+++ b/t/remake-subdir-only.sh
@@ -15,7 +15,7 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Make sure remaking rules in subdir are correctly generated.
-# See also sister "grepping" test 'remake.sh'.
+# See also sister "grepping" test 'remake-subdir-grepping.sh'.
. ./defs || exit 1
diff --git a/t/remake8a.sh b/t/remake-makefile-intree.sh
index 405698bfc..cb7c425dc 100755
--- a/t/remake8a.sh
+++ b/t/remake-makefile-intree.sh
@@ -18,8 +18,8 @@
# This testcase checks dependency of generated Makefile from Makefile.am,
# configure.ac, acinclude.m4, aclocal.m4, and extra m4 files considered
# by aclocal.
# Keep this in sync with sister test 'remake8b.sh', which performs the
# same checks for a VPATH build.
. ./defs || exit 1
@@ -43,7 +43,7 @@ $ACLOCAL
$AUTOCONF
$AUTOMAKE
-srcdir='.' # To make syncing with remake8b.sh easier.
+srcdir='.' # To make syncing with remake-makefile-vpath.sh easier.
$srcdir/configure
@@ -18,8 +18,8 @@
# configure.ac, acinclude.m4, aclocal.m4, and extra m4 files considered
# by aclocal.
-# Keep this in sync with sister test 'remake8b.sh', which performs the
-# same checks for a VPATH build.
+# Keep this in sync with sister test 'remake-makefile-vpath.sh', which
+# performs the same checks for a VPATH build.
. ./defs || exit 1
diff --git a/t/remake8b.sh b/t/remake-makefile-vpath.sh
index 0fa910ca0..7e37fe856 100755
--- a/t/remake8b.sh
+++ b/t/remake-makefile-vpath.sh
@@ -18,8 +18,8 @@
# This testcase checks dependency of generated Makefile from Makefile.am,
# configure.ac, acinclude.m4, aclocal.m4, and extra m4 files considered
# by aclocal.
# Keep this in sync with sister test 'remake8a.sh', which performs the
# same checks for a in-tree build.
. ./defs || exit 1
@@ -45,7 +45,7 @@ $AUTOMAKE
mkdir build
cd build
-srcdir='..' # To make syncing with remake8a.sh easier.
+srcdir='..' # To make syncing with remake-makefile-intree.sh easier.
$srcdir/configure
@@ -18,8 +18,8 @@
# configure.ac, acinclude.m4, aclocal.m4, and extra m4 files considered
# by aclocal.
-# Keep this in sync with sister test 'remake8a.sh', which performs the
-# same checks for a in-tree build.
+# Keep this in sync with sister test 'remake-makefile-instree.sh', which
+# performs the same checks for a in-tree build.
. ./defs || exit 1